SupabaseCrashlyticsAddons class

Crashlytics is a crash reporter that helps you track, prioritize, and fix stability issues that erode your app quality.

Create a table called crashlytics on the database:

create table public.crashlytics (
  exception text not null,
  stackTraceElements json,
  reason text,
  fatal bool,
  timestamp text,
  version text
);

Initialize the crashlytics addon:

SupabaseCrashlyticsAddons.initialize();

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

collectionEnabled ↔ bool
Whether the data collection is enabled. This is usually disabled when debugging the project, and is only enabled on production
getter/setter pair
tableName → String
The supabase database table name used by this addon
no setter

Static Methods

dispose() → void
Dispose the addon to free up resources
initialize({bool? collectionEnabled, String tableName = 'crashlytics'}) → void
Initiailize the crashlytics addon
recordError(dynamic exception, StackTrace? stack, {String? reason, bool fatal = false, bool printDetails = true, Map<String, dynamic>? moreInfo}) → Future<void>
Submits a Crashlytics report of a caught error.